@@ -1,5 +1,5 @@
 /**********************************************************************
-  iso8859_15.c -  Oniguruma (regular expression library)
+  iso8859_10.c -  Oniguruma (regular expression library)
 **********************************************************************/
 /*-
  * Copyright (c) 2002-2006  K.Kosako  <sndgk393 AT ybb DOT ne DOT jp>
@@ -29,11 +29,11 @@
 
 #include "regenc.h"
 
-#define ENC_ISO_8859_15_TO_LOWER_CASE(c) EncISO_8859_15_ToLowerCaseTable[c]
-#define ENC_IS_ISO_8859_15_CTYPE(code,ctype) \
-  ((EncISO_8859_15_CtypeTable[code] & CTYPE_TO_BIT(ctype)) != 0)
+#define ENC_ISO_8859_10_TO_LOWER_CASE(c) EncISO_8859_10_ToLowerCaseTable[c]
+#define ENC_IS_ISO_8859_10_CTYPE(code,ctype) \
+  ((EncISO_8859_10_CtypeTable[code] & CTYPE_TO_BIT(ctype)) != 0)
 
-static const UChar EncISO_8859_15_ToLowerCaseTable[256] = {
+static const UChar EncISO_8859_10_ToLowerCaseTable[256] = {
   '\000', '\001', '\002', '\003', '\004', '\005', '\006', '\007',
   '\010', '\011', '\012', '\013', '\014', '\015', '\016', '\017',
   '\020', '\021', '\022', '\023', '\024', '\025', '\026', '\027',
@@ -54,13 +54,13 @@ static const UChar EncISO_8859_15_ToLowerCaseTable[256] = {
   '\210', '\211', '\212', '\213', '\214', '\215', '\216', '\217',
   '\220', '\221', '\222', '\223', '\224', '\225', '\226', '\227',
   '\230', '\231', '\232', '\233', '\234', '\235', '\236', '\237',
-  '\240', '\241', '\242', '\243', '\244', '\245', '\250', '\247',
-  '\250', '\251', '\252', '\253', '\254', '\255', '\256', '\257',
-  '\260', '\261', '\262', '\263', '\270', '\265', '\266', '\267',
-  '\270', '\271', '\272', '\273', '\275', '\275', '\377', '\277',
+  '\240', '\261', '\262', '\263', '\264', '\265', '\266', '\247',
+  '\270', '\271', '\272', '\273', '\274', '\255', '\276', '\277',
+  '\260', '\261', '\262', '\263', '\264', '\265', '\266', '\267',
+  '\270', '\271', '\272', '\273', '\274', '\275', '\276', '\277',
   '\340', '\341', '\342', '\343', '\344', '\345', '\346', '\347',
   '\350', '\351', '\352', '\353', '\354', '\355', '\356', '\357',
-  '\360', '\361', '\362', '\363', '\364', '\365', '\366', '\327',
+  '\360', '\361', '\362', '\363', '\364', '\365', '\366', '\367',
   '\370', '\371', '\372', '\373', '\374', '\375', '\376', '\337',
   '\340', '\341', '\342', '\343', '\344', '\345', '\346', '\347',
   '\350', '\351', '\352', '\353', '\354', '\355', '\356', '\357',
@@ -68,7 +68,7 @@ static const UChar EncISO_8859_15_ToLowerCaseTable[256] = {
   '\370', '\371', '\372', '\373', '\374', '\375', '\376', '\377'
 };
 
-static const unsigned short EncISO_8859_15_CtypeTable[256] = {
+static const unsigned short EncISO_8859_10_CtypeTable[256] = {
   0x4008, 0x4008, 0x4008, 0x4008, 0x4008, 0x4008, 0x4008, 0x4008,
   0x4008, 0x420c, 0x4209, 0x4208, 0x4208, 0x4208, 0x4008, 0x4008,
   0x4008, 0x4008, 0x4008, 0x4008, 0x4008, 0x4008, 0x4008, 0x4008,
@@ -89,22 +89,22 @@ static const unsigned short EncISO_8859_15_CtypeTable[256] = {
   0x0008, 0x0008, 0x0008, 0x0008, 0x0008, 0x0008, 0x0008, 0x0008,
   0x0008, 0x0008, 0x0008, 0x0008, 0x0008, 0x0008, 0x0008, 0x0008,
   0x0008, 0x0008, 0x0008, 0x0008, 0x0008, 0x0008, 0x0008, 0x0008,
-  0x0284, 0x01a0, 0x00a0, 0x00a0, 0x00a0, 0x00a0, 0x34a2, 0x00a0,
-  0x30e2, 0x00a0, 0x30e2, 0x01a0, 0x00a0, 0x01a0, 0x00a0, 0x00a0,
-  0x00a0, 0x00a0, 0x10a0, 0x10a0, 0x34a2, 0x30e2, 0x00a0, 0x01a0,
-  0x30e2, 0x10a0, 0x30e2, 0x01a0, 0x34a2, 0x30e2, 0x34a2, 0x01a0,
+  0x0284, 0x34a2, 0x34a2, 0x34a2, 0x34a2, 0x34a2, 0x34a2, 0x00a0,
+  0x34a2, 0x34a2, 0x34a2, 0x34a2, 0x34a2, 0x01a0, 0x34a2, 0x34a2,
+  0x00a0, 0x30e2, 0x30e2, 0x30e2, 0x30e2, 0x30e2, 0x30e2, 0x01a0,
+  0x30e2, 0x30e2, 0x30e2, 0x30e2, 0x30e2, 0x01a0, 0x30e2, 0x30e2,
+  0x34a2, 0x34a2, 0x34a2, 0x34a2, 0x34a2, 0x34a2, 0x34a2, 0x34a2,
   0x34a2, 0x34a2, 0x34a2, 0x34a2, 0x34a2, 0x34a2, 0x34a2, 0x34a2,
   0x34a2, 0x34a2, 0x34a2, 0x34a2, 0x34a2, 0x34a2, 0x34a2, 0x34a2,
-  0x34a2, 0x34a2, 0x34a2, 0x34a2, 0x34a2, 0x34a2, 0x34a2, 0x00a0,
   0x34a2, 0x34a2, 0x34a2, 0x34a2, 0x34a2, 0x34a2, 0x34a2, 0x30e2,
   0x30e2, 0x30e2, 0x30e2, 0x30e2, 0x30e2, 0x30e2, 0x30e2, 0x30e2,
   0x30e2, 0x30e2, 0x30e2, 0x30e2, 0x30e2, 0x30e2, 0x30e2, 0x30e2,
-  0x30e2, 0x30e2, 0x30e2, 0x30e2, 0x30e2, 0x30e2, 0x30e2, 0x00a0,
+  0x30e2, 0x30e2, 0x30e2, 0x30e2, 0x30e2, 0x30e2, 0x30e2, 0x30e2,
   0x30e2, 0x30e2, 0x30e2, 0x30e2, 0x30e2, 0x30e2, 0x30e2, 0x30e2
 };
 
 static int
-iso_8859_15_mbc_case_fold(OnigCaseFoldType flag,
+iso_8859_10_mbc_case_fold(OnigCaseFoldType flag,
 			  const UChar** pp, const UChar* end, UChar* lower)
 {
   const UChar* p = *pp;
@@ -116,14 +116,14 @@ iso_8859_15_mbc_case_fold(OnigCaseFoldType flag,
     return 2;
   }
 
-  *lower = ENC_ISO_8859_15_TO_LOWER_CASE(*p);
+  *lower = ENC_ISO_8859_10_TO_LOWER_CASE(*p);
   (*pp)++;
-  return 1; /* return byte length of converted char to lower */
+  return 1;
 }
 
 #if 0
 static int
-iso_8859_15_is_mbc_ambiguous(OnigCaseFoldType flag,
+iso_8859_10_is_mbc_ambiguous(OnigCaseFoldType flag,
 			     const UChar** pp, const UChar* end)
 {
   int v;
@@ -135,13 +135,9 @@ iso_8859_15_is_mbc_ambiguous(OnigCaseFoldType flag,
   }
 
   (*pp)++;
-  v = (EncISO_8859_15_CtypeTable[*p] & (BIT_CTYPE_UPPER | BIT_CTYPE_LOWER));
+  v = (EncISO_8859_10_CtypeTable[*p] & (BIT_CTYPE_UPPER | BIT_CTYPE_LOWER));
   if ((v | BIT_CTYPE_LOWER) != 0) {
-    /* 0xdf etc.. are lower case letter, but can't convert. */
-    if (*p == 0xaa || *p == 0xb5 || *p == 0xba)
-      return FALSE;
-    else
-      return TRUE;
+    return TRUE;
   }
 
   return (v != 0 ? TRUE : FALSE);
@@ -149,20 +145,28 @@ iso_8859_15_is_mbc_ambiguous(OnigCaseFoldType flag,
 #endif
 
 static int
-iso_8859_15_is_code_ctype(OnigCodePoint code, unsigned int ctype)
+iso_8859_10_is_code_ctype(OnigCodePoint code, unsigned int ctype)
 {
   if (code < 256)
-    return ENC_IS_ISO_8859_15_CTYPE(code, ctype);
+    return ENC_IS_ISO_8859_10_CTYPE(code, ctype);
   else
     return FALSE;
 }
 
 static const OnigPairCaseFoldCodes CaseFoldMap[] = {
-  { 0xa6, 0xa8 },
-
-  { 0xb4, 0xb8 },
-  { 0xbc, 0xbd },
-  { 0xbe, 0xff },
+  { 0xa1, 0xb1 },
+  { 0xa2, 0xb2 },
+  { 0xa3, 0xb3 },
+  { 0xa4, 0xb4 },
+  { 0xa5, 0xb5 },
+  { 0xa6, 0xb6 },
+  { 0xa8, 0xb8 },
+  { 0xa9, 0xb9 },
+  { 0xaa, 0xba },
+  { 0xab, 0xbb },
+  { 0xac, 0xbc },
+  { 0xae, 0xbe },
+  { 0xaf, 0xbf },
 
   { 0xc0, 0xe0 },
   { 0xc1, 0xe1 },
@@ -188,6 +192,7 @@ static const OnigPairCaseFoldCodes CaseFoldMap[] = {
   { 0xd4, 0xf4 },
   { 0xd5, 0xf5 },
   { 0xd6, 0xf6 },
+  { 0xd7, 0xf7 },
   { 0xd8, 0xf8 },
   { 0xd9, 0xf9 },
   { 0xda, 0xfa },
@@ -198,7 +203,7 @@ static const OnigPairCaseFoldCodes CaseFoldMap[] = {
 };
 
 static int
-iso_8859_15_apply_all_case_fold(OnigCaseFoldType flag,
+iso_8859_10_apply_all_case_fold(OnigCaseFoldType flag,
 			       OnigApplyAllCaseFoldFunc f, void* arg)
 {
   return onigenc_apply_all_case_fold_with_map(
@@ -207,7 +212,7 @@ iso_8859_15_apply_all_case_fold(OnigCaseFoldType flag,
 }
 
 static int
-iso_8859_15_get_case_fold_codes_by_str(OnigCaseFoldType flag,
+iso_8859_10_get_case_fold_codes_by_str(OnigCaseFoldType flag,
     const OnigUChar* p, const OnigUChar* end, OnigCaseFoldCodeItem items[])
 {
   return onigenc_get_case_fold_codes_by_str_with_map(
@@ -215,20 +220,20 @@ iso_8859_15_get_case_fold_codes_by_str(OnigCaseFoldType flag,
 	     flag, p, end, items);
 }
 
-OnigEncodingType OnigEncodingISO_8859_15 = {
+OnigEncodingType OnigEncodingISO_8859_10 = {
   onigenc_single_byte_mbc_enc_len,
-  "ISO-8859-15",  /* name */
+  "ISO-8859-10", /* name */
   1,             /* max enc length */
   1,             /* min enc length */
   onigenc_is_mbc_newline_0x0a,
   onigenc_single_byte_mbc_to_code,
   onigenc_single_byte_code_to_mbclen,
   onigenc_single_byte_code_to_mbc,
-  iso_8859_15_mbc_case_fold,
-  iso_8859_15_apply_all_case_fold,
-  iso_8859_15_get_case_fold_codes_by_str,
+  iso_8859_10_mbc_case_fold,
+  iso_8859_10_apply_all_case_fold,
+  iso_8859_10_get_case_fold_codes_by_str,
   onigenc_minimum_property_name_to_ctype,
-  iso_8859_15_is_code_ctype,
+  iso_8859_10_is_code_ctype,
   onigenc_not_support_get_ctype_code_range,
   onigenc_single_byte_left_adjust_char_head,
   onigenc_always_true_is_allowed_reverse_match
